@@ -67,7 +67,9 @@ namespace Phonon
             }
             return ret;
         }
-                
+
+
+/*
         static HRESULT saveToFile(Graph graph, const QString &filepath)
         {
             const WCHAR wszStreamName[] = L"ActiveMovieGraph";
@@ -103,12 +105,12 @@ namespace Phonon
 
             return hr;
         }
-
+*/
 
         MediaGraph::MediaGraph(MediaObject *mo, short index) :
             m_graph(CLSID_FilterGraph, IID_IGraphBuilder),
             m_fakeSource(new FakeSource()),
-            m_hasVideo(false), m_hasAudio(false), m_connectionsDirty(false), 
+            m_hasVideo(false), m_hasAudio(false), m_connectionsDirty(false),
             m_isStopping(false), m_isSeekable(false), m_result(S_OK),
             m_index(index), m_renderId(0), m_seekId(0),
             m_currentTime(0), m_totalTime(0), m_mediaObject(mo)
@@ -350,7 +352,7 @@ namespace Phonon
             m_isStopping = true;
             //special case here because we want stopped to be synchronous
             m_graph->Abort();
-            m_mediaControl->Stop(); 
+            m_mediaControl->Stop();
             OAFilterState dummy;
             //this will wait until the change is effective
             m_mediaControl->GetState(INFINITE, &dummy);
@@ -377,11 +379,12 @@ namespace Phonon
             FILTER_INFO info;
             filter->QueryFilterInfo(&info);
 #ifdef GRAPH_DEBUG
-            qDebug() << "removeFilter" << QString::fromUtf16(info.achName);
+            qDebug() << "removeFilter" << QString((const QChar *)info.achName);
 #endif
             if (info.pGraph) {
                 info.pGraph->Release();
-                return m_graph->RemoveFilter(filter);
+                if (info.pGraph == m_graph)
+                    return m_graph->RemoveFilter(filter);
             }
 
             //already removed
@@ -537,7 +540,7 @@ namespace Phonon
                     const QList<OutputPin> outputs = BackendNode::pins(filter, PINDIR_OUTPUT);
                     for(int i = 0; i < outputs.count(); ++i) {
                         const OutputPin &pin = outputs.at(i);
-                        if (VFW_E_NOT_CONNECTED == pin->ConnectedTo(inPin.pparam())) {
+                        if (HRESULT(VFW_E_NOT_CONNECTED) == pin->ConnectedTo(inPin.pparam())) {
                             return SUCCEEDED(pin->Connect(newIn, 0));
                         }
                     }
@@ -615,7 +618,7 @@ namespace Phonon
             bool ret = false;
             const QList<InputPin> inputs = BackendNode::pins(sink->filter(m_index), PINDIR_INPUT);
             QList<OutputPin> outputs = BackendNode::pins(source == m_mediaObject ? m_fakeSource : source->filter(m_index), PINDIR_OUTPUT);
-            
+
             if (source == m_mediaObject) {
                 grabFilter(m_fakeSource);
             }
@@ -679,7 +682,6 @@ namespace Phonon
  #ifndef QT_NO_PHONON_MEDIACONTROLLER
                } else if (source.discType() == Phonon::Cd) {
                     m_realSource = Filter(new QAudioCDPlayer);
-                    m_result = m_graph->AddFilter(m_realSource, 0);
 
 #endif //QT_NO_PHONON_MEDIACONTROLLER
                 } else {
@@ -809,7 +811,7 @@ namespace Phonon
                 for (int i = 0; i < outputs.count(); ++i) {
                     const OutputPin &out = outputs.at(i);
                     InputPin pin;
-                    if (out->ConnectedTo(pin.pparam()) == VFW_E_NOT_CONNECTED) {
+                    if (out->ConnectedTo(pin.pparam()) == HRESULT(VFW_E_NOT_CONNECTED)) {
                         m_decoderPins += out; //unconnected outputs can be decoded outputs
                     }
                 }
@@ -873,7 +875,7 @@ namespace Phonon
             {
                 FILTER_INFO info;
                 filter->QueryFilterInfo(&info);
-                qDebug() << Q_FUNC_INFO << QString::fromUtf16(info.achName);
+                qDebug() << Q_FUNC_INFO << QString((const QChar *)info.achName);
                 if (info.pGraph) {
                     info.pGraph->Release();
                 }
@@ -919,7 +921,7 @@ namespace Phonon
             {
                 FILTER_INFO info;
                 filter->QueryFilterInfo(&info);
-                qDebug() << "found a decoder filter" << QString::fromUtf16(info.achName);
+                qDebug() << "found a decoder filter" << QString((const QChar *)info.achName);
                 if (info.pGraph) {
                     info.pGraph->Release();
                 }
@@ -935,7 +937,7 @@ namespace Phonon
             {
                 FILTER_INFO info;
                 filter->QueryFilterInfo(&info);
-                qDebug() << Q_FUNC_INFO << QString::fromUtf16(info.achName);
+                qDebug() << Q_FUNC_INFO << QString((const QChar *)info.achName);
                 if (info.pGraph) {
                     info.pGraph->Release();
                 }
@@ -954,7 +956,7 @@ namespace Phonon
             {
                 FILTER_INFO info;
                 filter->QueryFilterInfo(&info);
-                qDebug() << Q_FUNC_INFO << QString::fromUtf16(info.achName);
+                qDebug() << Q_FUNC_INFO << QString((const QChar *)info.achName);
                 if (info.pGraph) {
                     info.pGraph->Release();
                 }
@@ -979,7 +981,7 @@ namespace Phonon
                 QAMMediaType type;
                 //for now we support only video and audio
                 hr = outputs.at(i)->ConnectionMediaType(&type);
-                if (SUCCEEDED(hr) && 
+                if (SUCCEEDED(hr) &&
                     type.majortype != MEDIATYPE_Video && type.majortype != MEDIATYPE_Audio) {
                         return false;
                 }
@@ -988,7 +990,7 @@ namespace Phonon
             {
                 FILTER_INFO info;
                 filter->QueryFilterInfo(&info);
-                qDebug() << "found a demuxer filter" << QString::fromUtf16(info.achName);
+                qDebug() << "found a demuxer filter" << QString((const QChar *)info.achName);
                 if (info.pGraph) {
                     info.pGraph->Release();
                 }
@@ -1006,27 +1008,27 @@ namespace Phonon
                 BSTR str;
                 HRESULT hr = mediaContent->get_AuthorName(&str);
                 if (SUCCEEDED(hr)) {
-                    ret.insert(QLatin1String("ARTIST"), QString::fromUtf16((const unsigned short*)str));
+                    ret.insert(QLatin1String("ARTIST"), QString::fromUtf16((const unsigned short*) str));
                     SysFreeString(str);
                 }
                 hr = mediaContent->get_Title(&str);
                 if (SUCCEEDED(hr)) {
-                    ret.insert(QLatin1String("TITLE"), QString::fromUtf16((const unsigned short*)str));
+                    ret.insert(QLatin1String("TITLE"), QString::fromUtf16((const unsigned short*) str));
                     SysFreeString(str);
                 }
                 hr = mediaContent->get_Description(&str);
                 if (SUCCEEDED(hr)) {
-                    ret.insert(QLatin1String("DESCRIPTION"), QString::fromUtf16((const unsigned short*)str));
+                    ret.insert(QLatin1String("DESCRIPTION"), QString::fromUtf16((const unsigned short*) str));
                     SysFreeString(str);
                 }
                 hr = mediaContent->get_Copyright(&str);
                 if (SUCCEEDED(hr)) {
-                    ret.insert(QLatin1String("COPYRIGHT"), QString::fromUtf16((const unsigned short*)str));
+                    ret.insert(QLatin1String("COPYRIGHT"), QString::fromUtf16((const unsigned short*) str));
                     SysFreeString(str);
                 }
                 hr = mediaContent->get_MoreInfoText(&str);
                 if (SUCCEEDED(hr)) {
-                    ret.insert(QLatin1String("MOREINFO"), QString::fromUtf16((const unsigned short*)str));
+                    ret.insert(QLatin1String("MOREINFO"), QString::fromUtf16((const unsigned short*) str));
                     SysFreeString(str);
                 }
             }
@@ -1062,10 +1064,10 @@ namespace Phonon
             }
 
             if (shouldSeek) {
-                m_mediaSeeking->SetPositions(&current, AM_SEEKING_AbsolutePositioning, 
+                m_mediaSeeking->SetPositions(&current, AM_SEEKING_AbsolutePositioning,
                     &time, AM_SEEKING_AbsolutePositioning);
             } else {
-                m_mediaSeeking->SetPositions(0, AM_SEEKING_NoPositioning, 
+                m_mediaSeeking->SetPositions(0, AM_SEEKING_NoPositioning,
                     &time, AM_SEEKING_AbsolutePositioning);
             }
         }
