@@ -1,6 +1,6 @@
 /*  This file is part of the KDE project.
 
-Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 
 This library is free software: you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
@@ -92,8 +92,8 @@ namespace Phonon
                     return E_POINTER;
                 }
 
-                int nbfetched = 0;
-                while (nbfetched < int(count) && m_index < m_pins.count()) {
+                uint nbfetched = 0;
+                while (nbfetched < count && m_index < m_pins.count()) {
                     IPin *current = m_pins[m_index];
                     current->AddRef();
                     ret[nbfetched] = current;
@@ -166,19 +166,19 @@ namespace Phonon
 
         const QList<QPin *> QBaseFilter::pins() const
         {
-            QReadLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             return m_pins;
         }
 
         void QBaseFilter::addPin(QPin *pin)
         {
-            QWriteLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             m_pins.append(pin);
         }
 
         void QBaseFilter::removePin(QPin *pin)
         {
-            QWriteLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             m_pins.removeAll(pin);
         }
 
@@ -186,7 +186,7 @@ namespace Phonon
         {
             return m_state;
         }
-        
+
         IFilterGraph *QBaseFilter::graph() const
         {
             return m_graph;
@@ -211,7 +211,8 @@ namespace Phonon
             }
             else if (iid == IID_IMediaPosition || iid == IID_IMediaSeeking) {
                 if (inputPins().isEmpty()) {
-                    if (*out = getUpStreamInterface(iid)) {
+                    *out = getUpStreamInterface(iid);
+                    if (*out) {
                         return S_OK; //we return here to avoid adding a reference
                     } else {
                         hr = E_NOINTERFACE;
@@ -220,7 +221,7 @@ namespace Phonon
                     *out = static_cast<IMediaSeeking*>(this);
                 } else if (iid == IID_IMediaPosition ||iid == IID_IDispatch) {
                     *out = static_cast<IMediaPosition*>(this);
-                } 
+                }
             } else {
                 *out = 0;
                 hr = E_NOINTERFACE;
@@ -250,35 +251,35 @@ namespace Phonon
 
         STDMETHODIMP QBaseFilter::GetClassID(CLSID *clsid)
         {
-            QReadLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             *clsid = m_clsid;
             return S_OK;
         }
 
         STDMETHODIMP QBaseFilter::Stop()
         {
-            QWriteLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             m_state = State_Stopped;
             return S_OK;
         }
 
         STDMETHODIMP QBaseFilter::Pause()
         {
-            QWriteLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             m_state = State_Paused;
             return S_OK;
         }
 
         STDMETHODIMP QBaseFilter::Run(REFERENCE_TIME)
         {
-            QWriteLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             m_state = State_Running;
             return S_OK;
         }
 
         STDMETHODIMP QBaseFilter::GetState(DWORD, FILTER_STATE *state)
         {
-            QReadLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             if (!state) {
                 return E_POINTER;
             }
@@ -289,7 +290,7 @@ namespace Phonon
 
         STDMETHODIMP QBaseFilter::SetSyncSource(IReferenceClock *clock)
         {
-            QWriteLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             if (clock) {
                 clock->AddRef();
             }
@@ -302,7 +303,7 @@ namespace Phonon
 
         STDMETHODIMP QBaseFilter::GetSyncSource(IReferenceClock **clock)
         {
-            QReadLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             if (!clock) {
                 return E_POINTER;
             }
@@ -341,7 +342,7 @@ namespace Phonon
 
         STDMETHODIMP QBaseFilter::QueryFilterInfo(FILTER_INFO *info )
         {
-            QReadLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             if (!info) {
                 return E_POINTER;
             }
@@ -349,15 +350,15 @@ namespace Phonon
             if (m_graph) {
                 m_graph->AddRef();
             }
-            qMemCopy(info->achName, m_name.utf16(), qMin(MAX_FILTER_NAME, m_name.length()+1) *2);
+            memcpy(info->achName, m_name.utf16(), qMin(MAX_FILTER_NAME, m_name.length()+1) *2);
             return S_OK;
         }
 
         STDMETHODIMP QBaseFilter::JoinFilterGraph(IFilterGraph *graph, LPCWSTR name)
         {
-            QWriteLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             m_graph = graph;
-            m_name = QString::fromUtf16((const unsigned short*)name);
+            m_name = QString::fromUtf16((unsigned short*) name);
             return S_OK;
         }
 
@@ -499,7 +500,7 @@ namespace Phonon
             return hr;
         }
 
-        STDMETHODIMP QBaseFilter::ConvertTimeFormat(LONGLONG *pTarget, 
+        STDMETHODIMP QBaseFilter::ConvertTimeFormat(LONGLONG *pTarget,
             const GUID *pTargetFormat, LONGLONG Source, const GUID *pSourceFormat)
         {
             IMediaSeeking *ms = getUpstreamMediaSeeking();
@@ -753,7 +754,7 @@ namespace Phonon
             return hr;
         }
 
-        STDMETHODIMP QBaseFilter::Invoke(DISPID dispIdMember, REFIID riid, LCID lcid, WORD wFlags, DISPPARAMS *pDispParams, 
+        STDMETHODIMP QBaseFilter::Invoke(DISPID dispIdMember, REFIID riid, LCID lcid, WORD wFlags, DISPPARAMS *pDispParams,
             VARIANT *pVarResult, EXCEPINFO *pExcepInfo, UINT *puArgErr)
         {
             IMediaPosition *mp = getUpstreamMediaPosition();
