@@ -1,6 +1,6 @@
 /*  This file is part of the KDE project.
 
-Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 
 This library is free software: you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
@@ -28,8 +28,8 @@ namespace Phonon
     namespace DS9
     {
 
-        QMemInputPin::QMemInputPin(QBaseFilter *parent, const QVector<AM_MEDIA_TYPE> &mt, bool transform) : 
-            QPin(parent, PINDIR_INPUT, mt), m_shouldDuplicateSamples(true), m_transform(transform)
+        QMemInputPin::QMemInputPin(QBaseFilter *parent, const QVector<AM_MEDIA_TYPE> &mt, bool transform, QPin *output) :
+            QPin(parent, PINDIR_INPUT, mt), m_shouldDuplicateSamples(true), m_transform(transform), m_output(output)
         {
         }
 
@@ -66,11 +66,9 @@ namespace Phonon
         {
             //this allows to serialize with Receive calls
             QMutexLocker locker(&m_mutexReceive);
-            for(int i = 0; i < m_outputs.count(); ++i) {
-                IPin *conn = m_outputs.at(i)->connected();
-                if (conn) {
-                    conn->EndOfStream();
-                }
+            IPin *conn = m_output ? m_output->connected() : 0;
+            if (conn) {
+                conn->EndOfStream();
             }
             return S_OK;
         }
@@ -78,13 +76,11 @@ namespace Phonon
         STDMETHODIMP QMemInputPin::BeginFlush()
         {
             //pass downstream
-            for(int i = 0; i < m_outputs.count(); ++i) {
-                IPin *conn = m_outputs.at(i)->connected();
-                if (conn) {
-                    conn->BeginFlush();
-                }
+            IPin *conn = m_output ? m_output->connected() : 0;
+            if (conn) {
+                conn->BeginFlush();
             }
-            QWriteLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             m_flushing = true;
             return S_OK;
         }
@@ -92,22 +88,19 @@ namespace Phonon
         STDMETHODIMP QMemInputPin::EndFlush()
         {
             //pass downstream
-            for(int i = 0; i < m_outputs.count(); ++i) {
-                IPin *conn = m_outputs.at(i)->connected();
-                if (conn) {
-                    conn->EndFlush();
-                }
+            IPin *conn = m_output ? m_output->connected() : 0;
+            if (conn) {
+                conn->EndFlush();
             }
-            QWriteLocker locker(&m_lock);
+            QMutexLocker locker(&m_mutex);
             m_flushing = false;
             return S_OK;
         }
 
         STDMETHODIMP QMemInputPin::NewSegment(REFERENCE_TIME start, REFERENCE_TIME stop, double rate)
         {
-            for(int i = 0; i < m_outputs.count(); ++i) {
-                m_outputs.at(i)->NewSegment(start, stop, rate);
-            }
+            if (m_output)
+                m_output->NewSegment(start, stop, rate);
             return S_OK;
         }
 
@@ -119,14 +112,9 @@ namespace Phonon
             if (hr == S_OK &&
                 mt->majortype != MEDIATYPE_NULL &&
                 mt->subtype != MEDIASUBTYPE_NULL &&
-                mt->formattype != GUID_NULL) {
-                    //we tell the output pins that they should connect with this type
-                    for(int i = 0; i < m_outputs.count(); ++i) {
-                        hr = m_outputs.at(i)->setAcceptedMediaType(connectedType());
-                        if (FAILED(hr)) {
-                            break;
-                        }
-                    }
+                mt->formattype != GUID_NULL && m_output) {
+                    //we tell the output pin that it should connect with this type
+                    hr = m_output->setAcceptedMediaType(connectedType());
             }
             return hr;
         }
@@ -137,7 +125,8 @@ namespace Phonon
                 return E_POINTER;
             }
 
-            if (*alloc = memoryAllocator(true)) {
+            *alloc = memoryAllocator(true);
+            if (*alloc) {
                 return S_OK;
             }
 
@@ -151,18 +140,15 @@ namespace Phonon
             }
 
             {
-                QWriteLocker locker(&m_lock);
+                QMutexLocker locker(&m_mutex);
                 m_shouldDuplicateSamples = m_transform && readonly;
             }
 
             setMemoryAllocator(alloc);
 
-            for(int i = 0; i < m_outputs.count(); ++i) {
-                IPin *pin = m_outputs.at(i)->connected();
-                if (pin) {
-                    ComPointer<IMemInputPin> input(pin, IID_IMemInputPin);
-                    input->NotifyAllocator(alloc, m_shouldDuplicateSamples);
-                }
+            if (m_output) {
+                ComPointer<IMemInputPin> input(m_output, IID_IMemInputPin);
+                input->NotifyAllocator(alloc, m_shouldDuplicateSamples);
             }
 
             return S_OK;
@@ -201,22 +187,18 @@ namespace Phonon
                 }
             }
 
-            for (int i = 0; i < m_outputs.count(); ++i) {
-                QPin *current = m_outputs.at(i);
-                IMediaSample *outSample = m_shouldDuplicateSamples ? 
-                    duplicateSampleForOutput(sample, current->memoryAllocator())
+            if (m_output) {
+                IMediaSample *outSample = m_shouldDuplicateSamples ?
+                    duplicateSampleForOutput(sample, m_output->memoryAllocator())
                     : sample;
 
                 if (m_shouldDuplicateSamples) {
                     m_parent->processSample(outSample);
                 }
 
-                IPin *pin = current->connected();
-                if (pin) {
-                    ComPointer<IMemInputPin> input(pin, IID_IMemInputPin);
-                    if (input) {
-                        input->Receive(outSample);
-                    }
+                ComPointer<IMemInputPin> input(m_output->connected(), IID_IMemInputPin);
+                if (input) {
+                    input->Receive(outSample);
                 }
 
                 if (m_shouldDuplicateSamples) {
@@ -247,39 +229,16 @@ namespace Phonon
 
         STDMETHODIMP QMemInputPin::ReceiveCanBlock()
         {
-            //we test the output to see if they can block
-            for(int i = 0; i < m_outputs.count(); ++i) {
-                IPin *input = m_outputs.at(i)->connected();
-                if (input) {
-                    ComPointer<IMemInputPin> meminput(input, IID_IMemInputPin);
-                    if (meminput && meminput->ReceiveCanBlock() != S_FALSE) {
-                        return S_OK;
-                    }
+            //we test the output to see if it can block
+            if (m_output) {
+                ComPointer<IMemInputPin> meminput(m_output->connected(), IID_IMemInputPin);
+                if (meminput && meminput->ReceiveCanBlock() != S_FALSE) {
+                    return S_OK;
                 }
             }
             return S_FALSE;
         }
 
-        //addition
-        //this should be used by the filter to tell it's input pins to which output they should route the samples
-
-        void QMemInputPin::addOutput(QPin *output)
-        {
-            QWriteLocker locker(&m_lock);
-            m_outputs += output;
-        }
-
-        void QMemInputPin::removeOutput(QPin *output)
-        {
-            QWriteLocker locker(&m_lock);
-            m_outputs.removeOne(output);
-        }
-
-        QList<QPin*> QMemInputPin::outputs() const
-        {
-            QReadLocker locker(&m_lock);
-            return m_outputs;
-        }
 
         ALLOCATOR_PROPERTIES QMemInputPin::getDefaultAllocatorProperties() const
         {
@@ -294,7 +253,7 @@ namespace Phonon
             LONG length = sample->GetActualDataLength();
 
             HRESULT hr = alloc->Commit();
-            if (hr == VFW_E_SIZENOTSET) {
+            if (hr == HRESULT(VFW_E_SIZENOTSET)) {
                 ALLOCATOR_PROPERTIES prop = getDefaultAllocatorProperties();
                 prop.cbBuffer = qMax(prop.cbBuffer, length);
                 ALLOCATOR_PROPERTIES actual;
@@ -324,7 +283,7 @@ namespace Phonon
             {
                 LONGLONG start, end;
                 hr = sample->GetMediaTime(&start, &end);
-                if (hr != VFW_E_MEDIA_TIME_NOT_SET) {
+                if (hr != HRESULT(VFW_E_MEDIA_TIME_NOT_SET)) {
                     hr = out->SetMediaTime(&start, &end);
                     Q_ASSERT(SUCCEEDED(hr));
                 }
@@ -347,7 +306,7 @@ namespace Phonon
             hr = sample->GetPointer(&src);
             Q_ASSERT(SUCCEEDED(hr));
 
-            qMemCopy(dest, src, sample->GetActualDataLength());
+            memcpy(dest, src, sample->GetActualDataLength());
 
             return out;
         }
