@@ -23,7 +23,7 @@
 #include "gsthelper.h"
 
 #include <gst/gst.h>
-
+#ifndef QT_NO_PHONON_EFFECT
 QT_BEGIN_NAMESPACE
 
 namespace Phonon
@@ -40,7 +40,7 @@ AudioEffect::AudioEffect(Backend *backend, int effectId, QObject *parent)
         m_effectName = audioEffects[effectId]->name();
         init();
     } else {
-        Q_ASSERT(0); // Effect ID out of range
+        qWarning() << Q_FUNC_INFO << ": Effect ID (" << effectId << ") out of range (" << audioEffects.size() << ")!";
     }
 }
 
@@ -75,4 +75,5 @@ GstElement* AudioEffect::createEffectBin()
 } //namespace Phonon::Gstreamer
 
 QT_END_NAMESPACE
+#endif //QT_NO_PHONON_EFFECT
 #include "moc_audioeffect.cpp"
