@@ -1,6 +1,6 @@
 /*  This file is part of the KDE project.
 
-    Copyright (C) 2007 Trolltech ASA. All rights reserved.
+    Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 
     This library is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -20,7 +20,7 @@
 
 #include "common.h"
 
-#include <gst/gst.h>
+#include <gst/gstelement.h>
 
 QT_BEGIN_NAMESPACE
 
