@@ -15,6 +15,7 @@
     along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include <cmath>
+#include <gst/interfaces/navigation.h>
 #include <gst/interfaces/propertyprobe.h>
 #include <gst/pbutils/install-plugins.h>
 #include "common.h"
@@ -25,14 +26,15 @@
 #include "streamreader.h"
 #include "phononsrc.h"
 #include "phonon-config-gstreamer.h"
-#include <QtCore>
+
+#include <QtCore/QByteRef>
+#include <QtCore/QCoreApplication>
+#include <QtCore/QEvent>
+#include <QtCore/QFile>
+#include <QtCore/QLibrary>
+#include <QtCore/QStringList>
 #include <QtCore/QTimer>
 #include <QtCore/QVector>
-#include <QtCore/QFile>
-#include <QtCore/QByteRef>
-#include <QtCore/QStringList>
-#include <QtCore/QEvent>
-#include <QApplication>
 
 #define ABOUT_TO_FINNISH_TIME 2000
 #define MAX_QUEUE_TIME 20 * GST_SECOND
@@ -91,7 +93,7 @@ MediaObject::MediaObject(Backend *backend, QObject *parent)
     m_name = "MediaObject" + QString::number(count++);
 
     if (!m_backend->isValid()) {
-        setError(tr("Cannot start playback. \n\nCheck your Gstreamer installation and make sure you "
+        setError(tr("Cannot start playback. \n\nCheck your GStreamer installation and make sure you "
                     "\nhave libgstreamer-plugins-base installed."), Phonon::FatalError);
     } else {
         m_root = this;
@@ -210,7 +212,8 @@ void MediaObject::noMorePadsAvailable ()
 #ifdef PLUGIN_INSTALL_API
         GstInstallPluginsContext *ctx = gst_install_plugins_context_new ();
         gchar *details[2];
-        details[0] = m_missingCodecs[0].toLocal8Bit().data();
+        QByteArray missingCodec = m_missingCodecs.first().toLocal8Bit();
+        details[0] = missingCodec.data();
         details[1] = NULL;
         GstInstallPluginsReturn status;
 
@@ -222,8 +225,8 @@ void MediaObject::noMorePadsAvailable ()
             if( status == GST_INSTALL_PLUGINS_HELPER_MISSING )
                 setError(QString(tr("Missing codec helper script assistant.")), Phonon::FatalError );
             else
-                setError(QString(tr("Plugin codec installation failed for codec: %0"))
-                        .arg(m_missingCodecs[0].split("|")[3]), error);
+                setError(QString(tr("Plugin codec installation failed for codec: %1"))
+                        .arg(m_missingCodecs[0].split('|')[3]), error);
         }
         m_missingCodecs.clear();
 #else
@@ -260,23 +263,27 @@ void MediaObject::cb_unknown_type (GstElement *decodebin, GstPad *pad, GstCaps *
     QString value = "unknown codec";
 
     // These functions require GStreamer > 0.10.12
+#ifndef QT_NO_LIBRARY
     static Ptr_gst_pb_utils_init p_gst_pb_utils_init = 0;
     static Ptr_gst_pb_utils_get_codec_description p_gst_pb_utils_get_codec_description = 0;
     if (!p_gst_pb_utils_init) {
         p_gst_pb_utils_init =  (Ptr_gst_pb_utils_init)QLibrary::resolve(QLatin1String("gstpbutils-0.10"), 0, "gst_pb_utils_init");
         p_gst_pb_utils_get_codec_description =  (Ptr_gst_pb_utils_get_codec_description)QLibrary::resolve(QLatin1String("gstpbutils-0.10"), 0, "gst_pb_utils_get_codec_description");
         if (p_gst_pb_utils_init)
-	    p_gst_pb_utils_init();
+            p_gst_pb_utils_init();
     }
     if (p_gst_pb_utils_get_codec_description) {
         gchar *codecName = NULL;
         codecName = p_gst_pb_utils_get_codec_description (caps);
         value = QString::fromUtf8(codecName);
         g_free (codecName);
-    } else {
+    } else
+#endif //QT_NO_LIBRARY
+    {
         // For GStreamer versions < 0.10.12
         GstStructure *str = gst_caps_get_structure (caps, 0);
         value = QString::fromUtf8(gst_structure_get_name (str));
+
     }
 
 #ifdef PLUGIN_INSTALL_API
@@ -458,6 +465,7 @@ bool MediaObject::createPipefromURL(const QUrl &url)
  */
 bool MediaObject::createPipefromStream(const MediaSource &source)
 {
+#ifndef QT_NO_PHONON_ABSTRACTMEDIASTREAM
     // Remove any existing data source
     if (m_datasource) {
         gst_bin_remove(GST_BIN(m_pipeline), m_datasource);
@@ -479,6 +487,10 @@ bool MediaObject::createPipefromStream(const MediaSource &source)
         return false;
     }
     return true;
+#else //QT_NO_PHONON_ABSTRACTMEDIASTREAM
+    Q_UNUSED(source);
+    return false;
+#endif
 }
 
 void MediaObject::createPipeline()
@@ -487,7 +499,7 @@ void MediaObject::createPipeline()
     gst_object_ref (GST_OBJECT (m_pipeline));
     gst_object_sink (GST_OBJECT (m_pipeline));
 
-    m_decodebin = gst_element_factory_make ("decodebin", NULL);
+    m_decodebin = gst_element_factory_make ("decodebin2", NULL);
     g_signal_connect (m_decodebin, "new-decoded-pad", G_CALLBACK (&cb_newpad), this);
     g_signal_connect (m_decodebin, "unknown-type", G_CALLBACK (&cb_unknown_type), this);
     g_signal_connect (m_decodebin, "no-more-pads", G_CALLBACK (&cb_no_more_pads), this);
@@ -691,7 +703,7 @@ void MediaObject::setState(State newstate)
             m_backend->logMessage("EOS already reached", Backend::Info, this);
         } else if (currentState == GST_STATE_PLAYING) {
             changeState(Phonon::PlayingState);
-        } else if (!m_atEndOfStream && gst_element_set_state(m_pipeline, GST_STATE_PLAYING) != GST_STATE_CHANGE_FAILURE) {
+        } else if (gst_element_set_state(m_pipeline, GST_STATE_PLAYING) != GST_STATE_CHANGE_FAILURE) {
             m_pendingState = Phonon::PlayingState;
         } else {
             m_backend->logMessage("phonon state request failed", Backend::Info, this);
@@ -741,6 +753,8 @@ void MediaObject::changeState(State newstate)
 
     case Phonon::StoppedState:
         m_backend->logMessage("phonon state changed: Stopped", Backend::Info, this);
+        // We must reset the pipeline when playing again
+        m_resetNeeded = true;
         m_tickTimer->stop();
         break;
 
@@ -916,7 +930,9 @@ void MediaObject::setSource(const MediaSource &source)
     // Go into to loading state
     changeState(Phonon::LoadingState);
     m_loading = true;
-    m_resetNeeded = false;
+    // IMPORTANT: Honor the m_resetNeeded flag as it currently stands.
+    // See https://qa.mandriva.com/show_bug.cgi?id=56807
+    //m_resetNeeded = false;
     m_resumeState = false;
     m_pendingState = Phonon::StoppedState;
 
@@ -929,7 +945,7 @@ void MediaObject::setSource(const MediaSource &source)
     // Clear any existing errors
     m_aboutToFinishEmitted = false;
     m_error = NoError;
-    m_errorString = QString();
+    m_errorString.clear();
 
     m_bufferPercent = 0;
     m_prefinishMarkReachedNotEmitted = true;
@@ -949,17 +965,13 @@ void MediaObject::setSource(const MediaSource &source)
 
     switch (source.type()) {
     case MediaSource::Url: {
-            if (createPipefromURL(source.url()))
-                m_loading = true;
-            else
+            if (!createPipefromURL(source.url()))
                 setError(tr("Could not open media source."));
         }
         break;
 
     case MediaSource::LocalFile: {
-            if (createPipefromURL(QUrl::fromLocalFile(source.fileName())))
-                m_loading = true;
-            else
+            if (!createPipefromURL(QUrl::fromLocalFile(source.fileName())))
                 setError(tr("Could not open media source."));
         }
         break;
@@ -972,9 +984,7 @@ void MediaObject::setSource(const MediaSource &source)
         break;
 
     case MediaSource::Stream:
-        if (createPipefromStream(source))
-            m_loading = true;
-        else
+        if (!createPipefromStream(source))
             setError(tr("Could not open media source."));
         break;
 
@@ -998,9 +1008,7 @@ void MediaObject::setSource(const MediaSource &source)
                 qWarning() <<  "media " << source.discType() << " not implemented";
                 return;
             }
-            if (!mediaUrl.isEmpty() && createPipefromURL(QUrl(mediaUrl)))
-                m_loading = true;
-            else
+            if (mediaUrl.isEmpty() || !createPipefromURL(QUrl(mediaUrl)))
                 setError(tr("Could not open media source."));
         }
         break;
@@ -1016,8 +1024,7 @@ void MediaObject::setSource(const MediaSource &source)
 
     // We need to link this node to ensure that fake sinks are connected
     // before loading, otherwise the stream will be blocked
-    if (m_loading)
-        link();
+    link();
     beginLoad();
 }
 
@@ -1058,15 +1065,18 @@ void MediaObject::getStreamInfo()
         gint64 titleCount;
         GstFormat format = gst_format_get_by_nick("track");
         if (gst_element_query_duration (m_pipeline, &format, &titleCount)) {
-            int oldAvailableTitles = m_availableTitles;
-            m_availableTitles = (int)titleCount;
-            if (m_availableTitles != oldAvailableTitles) {
-                emit availableTitlesChanged(m_availableTitles);
-                m_backend->logMessage(QString("Available titles changed: %0").arg(m_availableTitles), Backend::Info, this);
+        //check if returned format is still "track",
+        //gstreamer sometimes returns the total time, if tracks information is not available.
+            if (qstrcmp(gst_format_get_name(format), "track") == 0)  {
+                int oldAvailableTitles = m_availableTitles;
+                m_availableTitles = (int)titleCount;
+                if (m_availableTitles != oldAvailableTitles) {
+                    emit availableTitlesChanged(m_availableTitles);
+                    m_backend->logMessage(QString("Available titles changed: %0").arg(m_availableTitles), Backend::Info, this);
+                }
             }
         }
     }
-
 }
 
 void MediaObject::setPrefinishMark(qint32 newPrefinishMark)
@@ -1266,7 +1276,7 @@ void MediaObject::handleBusMessage(const Message &message)
     switch (GST_MESSAGE_TYPE (gstMessage)) {
 
     case GST_MESSAGE_EOS:
-        m_backend->logMessage("EOS recieved", Backend::Info, this);
+        m_backend->logMessage("EOS received", Backend::Info, this);
         handleEndOfStream();
         break;
 
@@ -1365,7 +1375,7 @@ void MediaObject::handleBusMessage(const Message &message)
                     if (oldMap != m_metaData && !m_loading)
                         emit metaDataChanged(m_metaData);
                 }
-			}
+                        }
         }
         break;
 
@@ -1545,6 +1555,21 @@ void MediaObject::handleBusMessage(const Message &message)
     default:
         break;
     }
+
+    switch (gst_navigation_message_get_type(gstMessage)) {
+    case GST_NAVIGATION_MESSAGE_MOUSE_OVER: {
+        gboolean active;
+        if (!gst_navigation_message_parse_mouse_over(gstMessage, &active)) {
+            break;
+        }
+        MediaNodeEvent mouseOverEvent(MediaNodeEvent::VideoMouseOver, &active);
+        notify(&mouseOverEvent);
+        break;
+    }
+    default:
+        break;
+    }
+
 }
 
 void MediaObject::handleEndOfStream()
@@ -1587,6 +1612,14 @@ void MediaObject::handleEndOfStream()
     }
 }
 
+void MediaObject::invalidateGraph()
+{
+    m_resetNeeded = true;
+    if (m_state == Phonon::PlayingState || m_state == Phonon::PausedState) {
+        changeState(Phonon::StoppedState);
+    }
+}
+
 // Notifes the pipeline about state changes in the media object
 void MediaObject::notifyStateChange(Phonon::State newstate, Phonon::State oldstate)
 {
