@@ -1,6 +1,6 @@
 /*  This file is part of the KDE project.
 
-    Copyright (C) 2007 Trolltech ASA. All rights reserved.
+    Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 
     This library is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -18,11 +18,10 @@
 #ifndef Phonon_GSTREAMER_MESSAGE_H
 #define Phonon_GSTREAMER_MESSAGE_H
 
-#include "common.h"
-
 #include <QtCore/QMetaType>
 
-#include <gst/gst.h>
+#include <glib-2.0/glib/gmacros.h> // For G_*_DECLS macros primarily
+#include <gst/gstmessage.h>
 
 QT_BEGIN_NAMESPACE
 
