@@ -1,6 +1,6 @@
 /*  This file is part of the KDE project.
 
-Copyright (C) 2007 Trolltech ASA. All rights reserved.
+Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 
 This library is free software: you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
@@ -20,7 +20,7 @@ along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include <phonon/streaminterface.h>
 
 QT_BEGIN_NAMESPACE
-
+#ifndef QT_NO_PHONON_ABSTRACTMEDIASTREAM
 namespace Phonon
 {
 namespace Gstreamer
@@ -41,7 +41,7 @@ bool StreamReader::read(quint64 pos, int length, char * buffer)
             return false; // We didn't get any data
     }
 
-    qMemCopy(buffer, m_buffer.data(), length);
+    memcpy(buffer, m_buffer.data(), length);
     //truncate the buffer
     m_buffer = m_buffer.mid(pos);    
     return true;
@@ -49,5 +49,6 @@ bool StreamReader::read(quint64 pos, int length, char * buffer)
 
 }
 }
+#endif //QT_NO_PHONON_ABSTRACTMEDIASTREAM
 
 QT_END_NAMESPACE
