@@ -18,17 +18,11 @@
 #ifndef Phonon_GSTREAMER_VIDEOWIDGET_H
 #define Phonon_GSTREAMER_VIDEOWIDGET_H
 
-#include <phonon/videowidget.h>
 #include <phonon/videowidgetinterface.h>
 
-#include "backend.h"
-#include "common.h"
 #include "medianode.h"
-#include "abstractrenderer.h"
-#include "videowidget.h"
-
-#include <gst/gst.h>
 
+#ifndef QT_NO_PHONON_VIDEO
 QT_BEGIN_NAMESPACE
 
 class QString;
@@ -38,6 +32,9 @@ namespace Phonon
 namespace Gstreamer
 {
 
+class AbstractRenderer;
+class Backend;
+
 class VideoWidget : public QWidget, public Phonon::VideoWidgetInterface, public MediaNode
 {
     Q_OBJECT
@@ -85,6 +82,12 @@ public:
     }
 
 protected:
+    virtual void keyPressEvent(QKeyEvent *event);
+    virtual void keyReleaseEvent(QKeyEvent *event);
+    virtual void mouseMoveEvent(QMouseEvent *event);
+    virtual void mousePressEvent(QMouseEvent *event);
+    virtual void mouseReleaseEvent(QMouseEvent *event);
+
     GstElement *m_videoBin;
     QSize m_movieSize;
     AbstractRenderer *m_renderer;
@@ -103,5 +106,5 @@ private:
 } //namespace Phonon::Gstreamer
 
 QT_END_NAMESPACE
-
+#endif //QT_NO_PHONON_VIDEO
 #endif // Phonon_GSTREAMER_VIDEOWIDGET_H
