@@ -1,6 +1,6 @@
 /*  This file is part of the KDE project.
 
-    Copyright (C) 2007 Trolltech ASA. All rights reserved.
+    Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 
     This library is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -17,16 +17,21 @@
 
 #include "volumefadereffect.h"
 #include "common.h"
-#include <QtCore>
+
+#include <gst/gstbin.h>
+#include <gst/gstghostpad.h>
+#include <gst/gstutils.h>
+
+#include <QtCore/QEvent>
 
 QT_BEGIN_NAMESPACE
 
+#ifndef QT_NO_PHONON_VOLUMEFADEREFFECT
 namespace Phonon
 {
 namespace Gstreamer
 {
-
-VolumeFaderEffect::VolumeFaderEffect(Backend *backend, QObject *parent) 
+VolumeFaderEffect::VolumeFaderEffect(Backend *backend, QObject *parent)
     : Effect(backend, parent, AudioSource | AudioSink)
     , m_fadeCurve(Phonon::VolumeFaderEffect::Fade3Decibel)
     , m_fadeTimer(0)
@@ -127,10 +132,10 @@ void VolumeFaderEffect::updateFade()
             currVal = step;
             break;
         case Phonon::VolumeFaderEffect::Fade9Decibel: // Fast in the beginning / Linear
-            currVal = step * 0.5 + (1.0-(1.0-step)*(1.0-step)) * 0.5; 
+            currVal = step * 0.5 + (1.0-(1.0-step)*(1.0-step)) * 0.5;
             break;
         case Phonon::VolumeFaderEffect::Fade12Decibel: // Fast in the beginning
-            currVal = 1.0 - (1.0-step) * (1.0-step);  
+            currVal = 1.0 - (1.0-step) * (1.0-step);
             break;
         default:
             break;
@@ -156,7 +161,7 @@ bool VolumeFaderEffect::event(QEvent *event)
 }
 
 }} //namespace Phonon::Gstreamer
-
+#endif //QT_NO_PHONON_VOLUMEFADEREFFECT
 QT_END_NAMESPACE
 
 #include "moc_volumefadereffect.cpp"
