@@ -18,14 +18,14 @@
 #ifndef Phonon_GSTREAMER_WIDGETRENDERER_H
 #define Phonon_GSTREAMER_WIDGETRENDERER_H
 
-#include "videowidget.h"
-#include "common.h"
+#include "abstractrenderer.h"
 
 #ifndef QT_NO_OPENGL
 #include <QtOpenGL/QGLFormat>
 #include <QtOpenGL/QGLWidget>
 #endif
 
+#ifndef QT_NO_PHONON_VIDEO
 QT_BEGIN_NAMESPACE
 
 class QString;
@@ -35,6 +35,8 @@ namespace Phonon
 namespace Gstreamer
 {
 
+class VideoWidget;
+
 class WidgetRenderer : public AbstractRenderer
 {
 public:
@@ -59,5 +61,5 @@ private:
 } //namespace Phonon::Gstreamer
 
 QT_END_NAMESPACE
-
+#endif //QT_NO_PHONON_VIDEO
 #endif // Phonon_GSTREAMER_WIDGETRENDERER_H
