@@ -6,7 +6,7 @@
     License as published by the Free Software Foundation; either
     version 2.1 of the License, or (at your option) version 3, or any
     later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), Trolltech ASA 
+    successor approved by the membership of KDE e.V.), Nokia Corporation 
     (or its successors, if any) and the KDE Free Qt Foundation, which shall
     act as a proxy defined in Section 6 of version 3 of the license.
 
@@ -232,7 +232,7 @@ void MediaObject::setCurrentSource(const MediaSource &newSource)
         return;
     }
 
-    pDebug() << Q_FUNC_INFO << newSource.url();
+    pDebug() << Q_FUNC_INFO << newSource.type() << newSource.url() << newSource.deviceName();
 
     stop(); // first call stop as that often is the expected state
             // for setting a new URL
@@ -300,15 +300,15 @@ void MediaObject::enqueue(const MediaSource &source)
 
 void MediaObject::enqueue(const QList<MediaSource> &sources)
 {
-    foreach (const MediaSource &m, sources) {
-        enqueue(m);
+    for (int i = 0; i < sources.count(); ++i) {
+        enqueue(sources.at(i));
     }
 }
 
 void MediaObject::enqueue(const QList<QUrl> &urls)
 {
-    foreach (const QUrl &url, urls) {
-        enqueue(url);
+    for (int i = 0; i < urls.count(); ++i) {
+        enqueue(urls.at(i));
     }
 }
 
@@ -348,11 +348,6 @@ void MediaObjectPrivate::streamError(Phonon::ErrorType type, const QString &text
 void MediaObjectPrivate::_k_stateChanged(Phonon::State newstate, Phonon::State oldstate)
 {
     Q_Q(MediaObject);
-    if (mediaSource.type() != MediaSource::Url) {
-        // special handling only necessary for URLs because of the fallback
-        emit q->stateChanged(newstate, oldstate);
-        return;
-    }
 
     if (errorOverride) {
         errorOverride = false;
@@ -362,6 +357,12 @@ void MediaObjectPrivate::_k_stateChanged(Phonon::State newstate, Phonon::State o
         oldstate = ErrorState;
     }
 
+    if (mediaSource.type() != MediaSource::Url) {
+        // special handling only necessary for URLs because of the fallback
+        emit q->stateChanged(newstate, oldstate);
+        return;
+    }
+
     // backend MediaObject reached ErrorState, try a KioMediaSource
     if (newstate == Phonon::ErrorState && !kiofallback) {
         kiofallback = Platform::createMediaStream(mediaSource.url(), q);
@@ -502,8 +503,8 @@ void MediaObjectPrivate::setupBackendObject()
     }
 
 #ifndef QT_NO_PHONON_MEDIACONTROLLER
-    foreach (FrontendInterfacePrivate *f, interfaceList) {
-        f->_backendObjectChanged();
+    for (int i = 0 ; i < interfaceList.count(); ++i) {
+        interfaceList.at(i)->_backendObjectChanged();
     }
 #endif //QT_NO_PHONON_MEDIACONTROLLER
 
