@@ -6,7 +6,7 @@
     License as published by the Free Software Foundation; either
     version 2.1 of the License, or (at your option) version 3, or any
     later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), Trolltech ASA 
+    successor approved by the membership of KDE e.V.), Nokia Corporation 
     (or its successors, if any) and the KDE Free Qt Foundation, which shall
     act as a proxy defined in Section 6 of version 3 of the license.
 
@@ -50,7 +50,7 @@ MediaSource::MediaSource(const QString &filename)
     const QFileInfo fileInfo(filename);
     if (fileInfo.exists()) {
         bool localFs = QAbstractFileEngine::LocalDiskFlag & QFSFileEngine(filename).fileFlags(QAbstractFileEngine::LocalDiskFlag);
-        if (localFs) {
+        if (localFs && !filename.startsWith(QLatin1String(":/")) && !filename.startsWith(QLatin1String("qrc://"))) {
             d->url = QUrl::fromLocalFile(fileInfo.absoluteFilePath());
         } else {
 #ifndef QT_NO_PHONON_ABSTRACTMEDIASTREAM
@@ -58,6 +58,7 @@ MediaSource::MediaSource(const QString &filename)
             d->type = Stream;
             d->ioDevice = new QFile(filename);
             d->setStream(new IODeviceStream(d->ioDevice, d->ioDevice));
+            d->url =  QUrl::fromLocalFile(fileInfo.absoluteFilePath());
 #else
             d->type = Invalid;
 #endif //QT_NO_PHONON_ABSTRACTMEDIASTREAM
@@ -93,6 +94,54 @@ MediaSource::MediaSource(Phonon::DiscType dt, const QString &deviceName)
     d->deviceName = deviceName;
 }
 
+// NOTE: this is a protected constructor
+MediaSource::MediaSource(const DeviceAccess &access)
+    : d(new MediaSourcePrivate(CaptureDevice))
+{
+    if (access.first.isEmpty() || access.second.isEmpty()) {
+        d->type = Invalid;
+        return;
+    }
+    d->deviceAccessList.append(access);
+}
+
+#if !defined(QT_NO_PHONON_AUDIOCAPTURE) && !defined(QT_NO_PHONON_VIDEOCAPTURE)
+#endif //QT_NO_PHONON_AUDIOCAPTURE && QT_NO_PHONON_VIDEOCAPTURE
+
+#ifndef QT_NO_PHONON_AUDIOCAPTURE
+MediaSource::MediaSource(const Phonon::AudioCaptureDevice& acDevice)
+    : d(new MediaSourcePrivate(CaptureDevice))
+{
+    d->audioCaptureDevice = acDevice;
+
+    // Grab the device access list from the properties
+    if (acDevice.propertyNames().contains("deviceAccessList") &&
+        !acDevice.property("deviceAccessList").value<DeviceAccessList>().isEmpty()) {
+        d->deviceAccessList = acDevice.property("deviceAccessList").value<DeviceAccessList>();
+    } else {
+        // Invalidate the media source
+        d->type = Invalid;
+    }
+}
+#endif //QT_NO_PHONON_AUDIOCAPTURE
+
+#ifndef QT_NO_PHONON_VIDEOCAPTURE
+MediaSource::MediaSource(const Phonon::VideoCaptureDevice& vcDevice)
+    : d(new MediaSourcePrivate(CaptureDevice))
+{
+    d->videoCaptureDevice = vcDevice;
+
+    // Grab the device access list from the properties
+    if (vcDevice.propertyNames().contains("deviceAccessList") &&
+        !vcDevice.property("deviceAccessList").value<DeviceAccessList>().isEmpty()) {
+        d->deviceAccessList = vcDevice.property("deviceAccessList").value<DeviceAccessList>();
+    } else {
+        // Invalidate the media source
+        d->type = Invalid;
+    }
+}
+#endif //QT_NO_PHONON_VIDEOCAPTURE
+
 #ifndef QT_NO_PHONON_ABSTRACTMEDIASTREAM
 MediaSource::MediaSource(AbstractMediaStream *stream)
     : d(new MediaSourcePrivate(Stream))
@@ -140,8 +189,12 @@ MediaSourcePrivate::~MediaSourcePrivate()
 {
 #ifndef QT_NO_PHONON_ABSTRACTMEDIASTREAM
     if (autoDelete) {
-        delete stream;
-        delete ioDevice;
+        //here we use deleteLater because this object
+        //might be destroyed from another thread
+        if (stream)
+            stream->deleteLater();
+        if (ioDevice)
+            ioDevice->deleteLater();
     }
 #endif //QT_NO_PHONON_ABSTRACTMEDIASTREAM
 }
@@ -197,6 +250,11 @@ Phonon::DiscType MediaSource::discType() const
     return d->discType;
 }
 
+const DeviceAccessList& MediaSource::deviceAccessList() const
+{
+    return d->deviceAccessList;
+}
+
 QString MediaSource::deviceName() const
 {
     return d->deviceName;
@@ -214,16 +272,19 @@ void MediaSourcePrivate::setStream(AbstractMediaStream *s)
 }
 #endif //QT_NO_PHONON_ABSTRACTMEDIASTREAM
 
+#ifndef QT_NO_PHONON_AUDIOCAPTURE
+AudioCaptureDevice MediaSource::audioCaptureDevice() const
+{
+    return d->audioCaptureDevice;
+}
+#endif //QT_NO_PHONON_AUDIOCAPTURE
 
-//X AudioCaptureDevice MediaSource::audioCaptureDevice() const
-//X {
-//X     return d->audioCaptureDevice;
-//X }
-//X 
-//X VideoCaptureDevice MediaSource::videoCaptureDevice() const
-//X {
-//X     return d->videoCaptureDevice;
-//X }
+#ifndef QT_NO_PHONON_VIDEOCAPTURE
+VideoCaptureDevice MediaSource::videoCaptureDevice() const
+{
+    return d->videoCaptureDevice;
+}
+#endif //QT_NO_PHONON_VIDEOCAPTURE
 
 } // namespace Phonon
 
