@@ -29,7 +29,7 @@
 #include <QtCore/QStringList>
 #include "backendinterface.h"
 #include "platformplugin.h"
-#include "pulsesupport_p.h"
+#include "pulsesupport.h"
 
 QT_BEGIN_NAMESPACE
 
@@ -109,24 +109,36 @@ bool ObjectDescriptionData::isValid() const
 
 ObjectDescriptionData *ObjectDescriptionData::fromIndex(ObjectDescriptionType type, int index)
 {
-    BackendInterface *iface = qobject_cast<BackendInterface *>(Factory::backend());
+    bool is_audio_device = (AudioOutputDeviceType == type || AudioCaptureDeviceType == type);
+
+    PulseSupport *pulse = PulseSupport::getInstance();
+    if (is_audio_device && pulse->isActive()) {
+        QList<int> indexes = pulse->objectDescriptionIndexes(type);
+        if (indexes.contains(index)) {
+            QHash<QByteArray, QVariant> properties = pulse->objectDescriptionProperties(type, index);
+            return new ObjectDescriptionData(index, properties);
+        }
+
+        // When Pulse is enabled, only try from the platform plugin or backend if it is about audio capture
+        if (type != AudioCaptureDeviceType)
+            return new ObjectDescriptionData(0); // invalid
+    }
 
-    // prefer to get the ObjectDescriptionData from the platform plugin for audio devices
 #ifndef QT_NO_PHONON_PLATFORMPLUGIN
-    if (!iface || !PulseSupport::getInstance()->isActive()) {
-        if (type == AudioOutputDeviceType || type == AudioCaptureDeviceType) {
-            PlatformPlugin *platformPlugin = Factory::platformPlugin();
-            if (platformPlugin) {
-                QList<int> indexes = platformPlugin->objectDescriptionIndexes(type);
-                if (indexes.contains(index)) {
-                    QHash<QByteArray, QVariant> properties = platformPlugin->objectDescriptionProperties(type, index);
-                    return new ObjectDescriptionData(index, properties);
-                }
+    // prefer to get the ObjectDescriptionData from the platform plugin for audio devices
+    if (is_audio_device) {
+        PlatformPlugin *platformPlugin = Factory::platformPlugin();
+        if (platformPlugin) {
+            QList<int> indexes = platformPlugin->objectDescriptionIndexes(type);
+            if (indexes.contains(index)) {
+                QHash<QByteArray, QVariant> properties = platformPlugin->objectDescriptionProperties(type, index);
+                return new ObjectDescriptionData(index, properties);
             }
         }
     }
 #endif //QT_NO_PHONON_PLATFORMPLUGIN
 
+    BackendInterface *iface = qobject_cast<BackendInterface *>(Factory::backend());
     if (iface) {
         QList<int> indexes = iface->objectDescriptionIndexes(type);
         if (indexes.contains(index)) {
@@ -134,10 +146,29 @@ ObjectDescriptionData *ObjectDescriptionData::fromIndex(ObjectDescriptionType ty
             return new ObjectDescriptionData(index, properties);
         }
     }
+
     return new ObjectDescriptionData(0); // invalid
 }
 
 } //namespace Phonon
 
 QT_END_NAMESPACE
+
+
+void Phonon::registerMetaTypes()
+{
+    // Register the PhononDeviceAccessList type if it has not been registered yet
+    if (qMetaTypeId<Phonon::DeviceAccess>())
+    {
+        qRegisterMetaType<Phonon::DeviceAccess>();
+        qRegisterMetaTypeStreamOperators<Phonon::DeviceAccess>("Phonon::DeviceAccess");
+    }
+
+    if (qMetaTypeId<Phonon::DeviceAccessList>())
+    {
+        qRegisterMetaType<Phonon::DeviceAccessList>();
+        qRegisterMetaTypeStreamOperators<Phonon::DeviceAccessList>("Phonon::DeviceAccessList");
+    }
+}
+
 // vim: sw=4 ts=4
