@@ -23,7 +23,8 @@
 #include <QtCore/QAbstractEventDispatcher>
 #include <QtCore/QDebug>
 #include <QtCore/QStringList>
-#include <QTimer>
+#include <QtCore/QTimer>
+#include <QtCore/QMutex>
 
 #ifdef HAVE_PULSEAUDIO
 #include "pulsestream_p.h"
@@ -43,6 +44,7 @@ QT_BEGIN_NAMESPACE
 namespace Phonon
 {
 
+QMutex probeMutex;
 static PulseSupport* s_instance = NULL;
 
 #ifdef HAVE_PULSEAUDIO
@@ -75,8 +77,8 @@ static void logMessage(const QString &message, int priority, QObject *obj)
             QString className(obj->metaObject()->className());
             int nameLength = className.length() - className.lastIndexOf(':') - 1;
             className = className.right(nameLength);
-            output.sprintf("%s %s (%s %p)", message.toLatin1().constData(), 
-                           obj->objectName().toLatin1().constData(), 
+            output.sprintf("%s %s (%s %p)", message.toLatin1().constData(),
+                           obj->objectName().toLatin1().constData(),
                            className.toLatin1().constData(), obj);
         }
         else {
@@ -101,6 +103,10 @@ class AudioDevice
             properties["icon"] = icon;
             properties["available"] = (index != PA_INVALID_INDEX);
             properties["isAdvanced"] = false; // Nothing is advanced!
+
+            DeviceAccessList dal;
+            dal.append(DeviceAccess("pulse", desc));
+            properties["deviceAccessList"] = QVariant::fromValue<DeviceAccessList>(dal);
         }
 
         // Needed for QMap
@@ -118,7 +124,7 @@ bool operator!=(const AudioDevice &a, const AudioDevice &b)
 class PulseUserData
 {
     public:
-        inline 
+        inline
         PulseUserData()
         {
         }
@@ -653,7 +659,16 @@ static void context_state_callback(pa_context *c, void *)
 PulseSupport* PulseSupport::getInstance()
 {
     if (NULL == s_instance) {
-        s_instance = new PulseSupport();
+        /*
+         * In order to prevent the instance being used from multiple threads
+         * prior to it being contructed fully, we need to ensure we obtain a
+         * lock prior to creating it. After we aquire the lock, check to see
+         * if the object is created again before proceeding.
+         */
+        probeMutex.lock();
+        if (NULL == s_instance)
+            s_instance = new PulseSupport();
+        probeMutex.unlock();
     }
     return s_instance;
 }
@@ -702,7 +717,7 @@ PulseSupport::PulseSupport()
     // We require a glib event loop
     if (QLatin1String(QAbstractEventDispatcher::instance()->metaObject()->className())
             != "QGuiEventDispatcherGlib") {
-        logMessage("Disabling PulseAudio integration for lack of GLib event loop.");
+        qWarning("WARNING: Disabling PulseAudio integration for lack of GLib event loop.");
         return;
     }
 
@@ -915,12 +930,12 @@ static void setDevicePriority(Category category, QStringList list)
     char **devices;
     devices = pa_xnew(char *, list.size()+1);
     int i = 0;
-    foreach (QString str, list) {
+    foreach (const QString &str, list) {
         devices[i++] = pa_xstrdup(str.toUtf8().constData());
     }
     devices[list.size()] = NULL;
 
-#ifdef HAVE_PULSEAUDIO_DEVICE_MANAGER 
+#ifdef HAVE_PULSEAUDIO_DEVICE_MANAGER
     pa_operation *o;
     if (!(o = pa_ext_device_manager_reorder_devices_for_role(s_context, role.toUtf8().constData(), (const char**)devices, NULL, NULL)))
         logMessage(QString("pa_ext_device_manager_reorder_devices_for_role() failed"));
