@@ -24,7 +24,7 @@
 
 #include <qtest_kde.h>
 
-#include "../libkaudiodevicelist/audiodeviceenumerator.h"
+#include "phonon/audiodeviceenumerator.h"
 
 class SimpleTest : public QObject
 {
@@ -32,7 +32,8 @@ class SimpleTest : public QObject
 
     private Q_SLOTS:
         void sanityChecks();
-        void listDevices();
+        void listPlaybackDevices();
+        void listCaptureDevices();
         void checkCopy();
 };
 
@@ -43,7 +44,7 @@ void SimpleTest::sanityChecks()
     QVERIFY(AudioDeviceEnumerator::self() != 0);
 }
 
-void SimpleTest::listDevices()
+void SimpleTest::listPlaybackDevices()
 {
     QList<AudioDevice> deviceList = AudioDeviceEnumerator::availablePlaybackDevices();
     foreach (const AudioDevice &dev, deviceList) {
@@ -54,6 +55,17 @@ void SimpleTest::listDevices()
     }
 }
 
+void SimpleTest::listCaptureDevices()
+{
+    QList<AudioDevice> deviceList = AudioDeviceEnumerator::availableCaptureDevices();
+    foreach (const AudioDevice &dev, deviceList) {
+        qDebug() << dev.cardName() << dev.deviceIds() << dev.iconName() << dev.isAvailable();
+        foreach (const QString &id, dev.deviceIds()) {
+            QVERIFY(dev.deviceIds().count(id) == 1);
+        }
+    }
+}
+
 void SimpleTest::checkCopy()
 {
     QList<AudioDevice> deviceList = AudioDeviceEnumerator::availablePlaybackDevices();
