@@ -6,7 +6,7 @@
     License as published by the Free Software Foundation; either
     version 2.1 of the License, or (at your option) version 3, or any
     later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), Trolltech ASA 
+    successor approved by the membership of KDE e.V.), Nokia Corporation 
     (or its successors, if any) and the KDE Free Qt Foundation, which shall
     act as a proxy defined in Section 6 of version 3 of the license.
 
@@ -81,6 +81,8 @@ namespace QTest
             return qstrdup("QVariant::Double");
         case QVariant::Font:
             return qstrdup("QVariant::Font");
+        case QVariant::Hash:
+            return qstrdup("QVariant::Hash");
         case QVariant::Icon:
             return qstrdup("QVariant::Icon");
         case QVariant::Image:
